@@ -27,30 +27,30 @@ typedef enum {
   */
 } EBookQueryTest;
 
-EBookQuery* e_book_query_from_string  (const char *query_string);
-char*       e_book_query_to_string    (EBookQuery *q);
+EBookQuery* e_book_query_from_string  (const gchar *query_string);
+gchar *       e_book_query_to_string    (EBookQuery *q);
 
 EBookQuery* e_book_query_ref          (EBookQuery *q);
 void        e_book_query_unref        (EBookQuery *q);
 
-EBookQuery* e_book_query_and          (int nqs, EBookQuery **qs, gboolean unref);
+EBookQuery* e_book_query_and          (gint nqs, EBookQuery **qs, gboolean unref);
 EBookQuery* e_book_query_andv         (EBookQuery *q, ...);
-EBookQuery* e_book_query_or           (int nqs, EBookQuery **qs, gboolean unref);
+EBookQuery* e_book_query_or           (gint nqs, EBookQuery **qs, gboolean unref);
 EBookQuery* e_book_query_orv          (EBookQuery *q, ...);
 
 EBookQuery* e_book_query_not          (EBookQuery *q, gboolean unref);
 
 EBookQuery* e_book_query_field_exists (EContactField   field);
-EBookQuery* e_book_query_vcard_field_exists (const char *field);
+EBookQuery* e_book_query_vcard_field_exists (const gchar *field);
 EBookQuery* e_book_query_field_test   (EContactField   field,
 				       EBookQueryTest     test,
-				       const char        *value);
-EBookQuery* e_book_query_vcard_field_test (const char    *field,
+				       const gchar        *value);
+EBookQuery* e_book_query_vcard_field_test (const gchar    *field,
 				       EBookQueryTest     test,
-				       const char        *value);
+				       const gchar        *value);
 
 /* a special any field contains query */
-EBookQuery* e_book_query_any_field_contains (const char  *value);
+EBookQuery* e_book_query_any_field_contains (const gchar  *value);
 
 GType       e_book_query_get_type (void);
 EBookQuery* e_book_query_copy     (EBookQuery *q);
