@@ -40,6 +40,7 @@ G_BEGIN_DECLS
 #define E_IS_CAL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_CAL))
 #define E_IS_CAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), E_TYPE_CAL))
 
+#define E_TYPE_CAL_SOURCE_TYPE (e_cal_source_type_enum_get_type ())
 #define E_CAL_SET_MODE_STATUS_ENUM_TYPE (e_cal_set_mode_status_enum_get_type ())
 #define CAL_MODE_ENUM_TYPE                   (cal_mode_enum_get_type ())
 
@@ -81,7 +82,10 @@ struct _ECalClass {
 
 	/* Notification signals */
 
+	#ifndef E_CAL_DISABLE_DEPRECATED
 	void (* cal_opened) (ECal *ecal, ECalendarStatus status);
+	#endif
+	void (* cal_opened_ex) (ECal *ecal, const GError *error);
 	void (* cal_set_mode) (ECal *ecal, ECalSetModeStatus status, CalMode mode);
 
 	void (* backend_error) (ECal *ecal, const gchar *message);
@@ -95,7 +99,6 @@ typedef gchar * (* ECalAuthFunc) (ECal *ecal,
 
 GType e_cal_get_type (void);
 
-GType e_cal_open_status_enum_get_type (void);
 GType e_cal_source_type_enum_get_type (void);
 GType e_cal_set_mode_status_enum_get_type (void);
 GType cal_mode_enum_get_type (void);
