@@ -78,8 +78,6 @@ static gboolean opt_keep_running = FALSE;
 
 G_DEFINE_TYPE (EDataCalFactory, e_data_cal_factory, G_TYPE_OBJECT);
 
-#define E_DATA_CAL_FACTORY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), E_TYPE_DATA_CAL_FACTORY, EDataCalFactoryPrivate))
-
 struct _EDataCalFactoryPrivate {
 	EGdbusCalFactory *gdbus_object;
 
@@ -106,7 +104,7 @@ struct _EDataCalFactoryPrivate {
 };
 
 /* Forward Declarations */
-void e_data_cal_migrate (void);
+void e_data_cal_migrate_basedir (void);
 
 /* Create the EDataCalFactory error quark */
 GQuark
@@ -530,7 +528,8 @@ e_data_cal_factory_init (EDataCalFactory *factory)
 {
 	GError *error = NULL;
 
-	factory->priv = E_DATA_CAL_FACTORY_GET_PRIVATE (factory);
+	factory->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		factory, E_TYPE_DATA_CAL_FACTORY, EDataCalFactoryPrivate);
 
 	factory->priv->gdbus_object = e_gdbus_cal_factory_stub_new ();
 	g_signal_connect (factory->priv->gdbus_object, "handle-get-cal", G_CALLBACK (impl_CalFactory_getCal), factory);
@@ -987,7 +986,7 @@ main (gint argc, gchar **argv)
 		NULL);
 
 	/* Migrate user data from ~/.evolution to XDG base directories. */
-	e_data_cal_migrate ();
+	e_data_cal_migrate_basedir ();
 
 #ifndef G_OS_WIN32
 	setup_quit_signal ();
