@@ -49,10 +49,6 @@
 
 #define d(x) /*(printf("%s(%d): ", __FILE__, __LINE__),(x))*/
 
-#define CAMEL_MIME_PART_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_MIME_PART, CamelMimePartPrivate))
-
 typedef struct _AsyncContext AsyncContext;
 
 struct _CamelMimePartPrivate {
@@ -399,7 +395,7 @@ mime_part_finalize (GObject *object)
 {
 	CamelMimePartPrivate *priv;
 
-	priv = CAMEL_MIME_PART_GET_PRIVATE (object);
+	priv = CAMEL_MIME_PART (object)->priv;
 
 	g_free (priv->description);
 	g_free (priv->content_id);
@@ -919,7 +915,8 @@ camel_mime_part_init (CamelMimePart *mime_part)
 {
 	CamelDataWrapper *data_wrapper;
 
-	mime_part->priv = CAMEL_MIME_PART_GET_PRIVATE (mime_part);
+	mime_part->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		mime_part, CAMEL_TYPE_MIME_PART, CamelMimePartPrivate);
 	mime_part->priv->encoding = CAMEL_TRANSFER_ENCODING_DEFAULT;
 
 	data_wrapper = CAMEL_DATA_WRAPPER (mime_part);
@@ -1403,7 +1400,7 @@ camel_mime_part_set_filename (CamelMimePart *mime_part,
  *
  * Returns: %TRUE on success, %FALSE on error
  *
- * Since: 2.92
+ * Since: 3.0
  **/
 gboolean
 camel_mime_part_construct_from_parser_sync (CamelMimePart *mime_part,
@@ -1443,7 +1440,7 @@ camel_mime_part_construct_from_parser_sync (CamelMimePart *mime_part,
  * call camel_mime_part_construct_from_parser_finish() to get the result of
  * the operation.
  *
- * Since: 2.92
+ * Since: 3.0
  **/
 void
 camel_mime_part_construct_from_parser (CamelMimePart *mime_part,
@@ -1476,7 +1473,7 @@ camel_mime_part_construct_from_parser (CamelMimePart *mime_part,
  *
  * Returns: %TRUE on success, %FALSE on error
  *
- * Since: 2.92
+ * Since: 3.0
  **/
 gboolean
 camel_mime_part_construct_from_parser_finish (CamelMimePart *mime_part,
