@@ -9,7 +9,7 @@
 
 G_DEFINE_TYPE (ESoapMessage, e_soap_message, SOUP_TYPE_MESSAGE)
 
-typedef struct {
+struct _ESoapMessagePrivate {
 	/* Serialization fields */
 	xmlDocPtr doc;
 	xmlNodePtr last_node;
@@ -19,13 +19,12 @@ typedef struct {
 	xmlChar *env_uri;
 	gboolean body_started;
 	gchar *action;
-} ESoapMessagePrivate;
-#define E_SOAP_MESSAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), E_TYPE_SOAP_MESSAGE, ESoapMessagePrivate))
+};
 
 static void
 finalize (GObject *object)
 {
-	ESoapMessagePrivate *priv = E_SOAP_MESSAGE_GET_PRIVATE (object);
+	ESoapMessagePrivate *priv = E_SOAP_MESSAGE (object)->priv;
 
 	if (priv->doc)
 		xmlFreeDoc (priv->doc);
@@ -52,18 +51,19 @@ e_soap_message_class_init (ESoapMessageClass *e_soap_message_class)
 static void
 e_soap_message_init (ESoapMessage *msg)
 {
-	ESoapMessagePrivate *priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	msg->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		msg, E_TYPE_SOAP_MESSAGE, ESoapMessagePrivate);
 
 	/* initialize XML structures */
-	priv->doc = xmlNewDoc ((const xmlChar *)"1.0");
-	priv->doc->standalone = FALSE;
-	priv->doc->encoding = xmlCharStrdup ("UTF-8");
+	msg->priv->doc = xmlNewDoc ((const xmlChar *)"1.0");
+	msg->priv->doc->standalone = FALSE;
+	msg->priv->doc->encoding = xmlCharStrdup ("UTF-8");
 }
 
 static xmlNsPtr
 fetch_ns (ESoapMessage *msg, const gchar *prefix, const gchar *ns_uri)
 {
-	ESoapMessagePrivate *priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	ESoapMessagePrivate *priv = msg->priv;
 	xmlNsPtr ns = NULL;
 
 	if (prefix && ns_uri)
@@ -91,7 +91,7 @@ fetch_ns (ESoapMessage *msg, const gchar *prefix, const gchar *ns_uri)
  * Returns: the new #ESoapMessage (or %NULL if @uri_string could not be
  * parsed).
  *
- * Since: 2.92
+ * Since: 3.0
  */
 ESoapMessage *
 e_soap_message_new (const gchar *method, const gchar *uri_string,
@@ -126,7 +126,7 @@ e_soap_message_new (const gchar *method, const gchar *uri_string,
  *
  * Returns: the new #ESoapMessage
  *
- * Since: 2.92
+ * Since: 3.0
  */
 ESoapMessage *
 e_soap_message_new_from_uri (const gchar *method, SoupURI *uri,
@@ -141,7 +141,7 @@ e_soap_message_new_from_uri (const gchar *method, SoupURI *uri,
 			    SOUP_MESSAGE_URI, uri,
 			    NULL);
 
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	priv->doc->standalone = standalone;
 
@@ -164,7 +164,7 @@ e_soap_message_new_from_uri (const gchar *method, SoupURI *uri,
  *
  * Starts the top level SOAP Envelope element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_start_envelope (ESoapMessage *msg)
@@ -172,7 +172,7 @@ e_soap_message_start_envelope (ESoapMessage *msg)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	priv->last_node = priv->doc->xmlRootNode =
 		xmlNewDocNode (priv->doc, NULL, (const xmlChar *)"Envelope", NULL);
@@ -212,7 +212,7 @@ e_soap_message_start_envelope (ESoapMessage *msg)
  *
  * Closes the top level SOAP Envelope element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_end_envelope (ESoapMessage *msg)
@@ -226,7 +226,7 @@ e_soap_message_end_envelope (ESoapMessage *msg)
  *
  * Starts the SOAP Body element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_start_body (ESoapMessage *msg)
@@ -234,7 +234,7 @@ e_soap_message_start_body (ESoapMessage *msg)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	if (priv->body_started)
 		return;
@@ -252,7 +252,7 @@ e_soap_message_start_body (ESoapMessage *msg)
  *
  * Closes the SOAP Body element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_end_body (ESoapMessage *msg)
@@ -281,7 +281,7 @@ e_soap_message_end_body (ESoapMessage *msg)
  * Passing NULL for both @prefix and @ns_uri causes no prefix to be
  * used, and the element will be in the default namespace.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_start_element (ESoapMessage *msg,
@@ -292,7 +292,7 @@ e_soap_message_start_element (ESoapMessage *msg,
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	priv->last_node = xmlNewChild (priv->last_node, NULL, (const xmlChar *)name, NULL);
 
@@ -309,7 +309,7 @@ e_soap_message_start_element (ESoapMessage *msg,
  *
  * Closes the current message element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_end_element (ESoapMessage *msg)
@@ -317,7 +317,7 @@ e_soap_message_end_element (ESoapMessage *msg)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	priv->last_node = priv->last_node->parent;
 }
@@ -336,7 +336,7 @@ e_soap_message_end_element (ESoapMessage *msg)
  * e_soap_message_start_fault_detail(), and then
  * e_soap_message_start_element() to add arbitrary sub-elements.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_start_fault (ESoapMessage *msg,
@@ -347,7 +347,7 @@ e_soap_message_start_fault (ESoapMessage *msg,
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	priv->last_node = xmlNewChild (priv->last_node,
 				       priv->soap_ns,
@@ -369,7 +369,7 @@ e_soap_message_start_fault (ESoapMessage *msg,
  *
  * Closes the current SOAP Fault element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_end_fault (ESoapMessage *msg)
@@ -385,7 +385,7 @@ e_soap_message_end_fault (ESoapMessage *msg)
  * element. The faultdetail element allows arbitrary data to be sent
  * in a returned fault.
  *
- * Since: 2.92
+ * Since: 3.0
  **/
 void
 e_soap_message_start_fault_detail (ESoapMessage *msg)
@@ -393,7 +393,7 @@ e_soap_message_start_fault_detail (ESoapMessage *msg)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	priv->last_node = xmlNewChild (priv->last_node,
 				       priv->soap_ns,
@@ -407,7 +407,7 @@ e_soap_message_start_fault_detail (ESoapMessage *msg)
  *
  * Closes the current SOAP faultdetail element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_end_fault_detail (ESoapMessage *msg)
@@ -427,7 +427,7 @@ e_soap_message_end_fault_detail (ESoapMessage *msg)
  * This should be called after e_soap_message_start_envelope() and
  * before e_soap_message_start_body().
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_start_header (ESoapMessage *msg)
@@ -435,7 +435,7 @@ e_soap_message_start_header (ESoapMessage *msg)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	priv->last_node = xmlNewChild (priv->last_node, priv->soap_ns,
 				       (const xmlChar *)"Header", NULL);
@@ -447,7 +447,7 @@ e_soap_message_start_header (ESoapMessage *msg)
  *
  * Closes the current SOAP Header element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_end_header (ESoapMessage *msg)
@@ -467,7 +467,7 @@ e_soap_message_end_header (ESoapMessage *msg)
  *
  * Starts a new SOAP arbitrary header element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_start_header_element (ESoapMessage *msg,
@@ -480,7 +480,7 @@ e_soap_message_start_header_element (ESoapMessage *msg,
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	e_soap_message_start_element (msg, name, prefix, ns_uri);
 	if (actor_uri)
@@ -495,7 +495,7 @@ e_soap_message_start_header_element (ESoapMessage *msg,
  *
  * Closes the current SOAP header element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_end_header_element (ESoapMessage *msg)
@@ -510,7 +510,7 @@ e_soap_message_end_header_element (ESoapMessage *msg)
  *
  * Writes the stringified value of @i as the current element's content.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_write_int (ESoapMessage *msg, glong i)
@@ -527,7 +527,7 @@ e_soap_message_write_int (ESoapMessage *msg, glong i)
  *
  * Writes the stringified value of @d as the current element's content.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_write_double (ESoapMessage *msg, gdouble d)
@@ -546,7 +546,7 @@ e_soap_message_write_double (ESoapMessage *msg, gdouble d)
  * Writes the Base-64 encoded value of @string as the current
  * element's content.
  *
- * Since: 2.92
+ * Since: 3.0
  **/
 void
 e_soap_message_write_base64 (ESoapMessage *msg, const gchar *string, gint len)
@@ -564,7 +564,7 @@ e_soap_message_write_base64 (ESoapMessage *msg, const gchar *string, gint len)
  * Writes the stringified value of @timeval as the current element's
  * content.
  *
- * Since: 2.92
+ * Since: 3.0
  **/
 void
 e_soap_message_write_time (ESoapMessage *msg, const time_t *timeval)
@@ -580,7 +580,7 @@ e_soap_message_write_time (ESoapMessage *msg, const time_t *timeval)
  *
  * Writes the @string as the current element's content.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_write_string (ESoapMessage *msg, const gchar *string)
@@ -588,7 +588,7 @@ e_soap_message_write_string (ESoapMessage *msg, const gchar *string)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	xmlNodeAddContent (priv->last_node, (const xmlChar *)string);
 }
@@ -602,7 +602,7 @@ e_soap_message_write_string (ESoapMessage *msg, const gchar *string)
  * Writes the string buffer pointed to by @buffer as the current
  * element's content.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_write_buffer (ESoapMessage *msg, const gchar *buffer, gint len)
@@ -610,7 +610,7 @@ e_soap_message_write_buffer (ESoapMessage *msg, const gchar *buffer, gint len)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	xmlNodeAddContentLen (priv->last_node, (const xmlChar *)buffer, len);
 }
@@ -623,7 +623,7 @@ e_soap_message_write_buffer (ESoapMessage *msg, const gchar *buffer, gint len)
  * Sets the current element's XML schema xsi:type attribute, which
  * specifies the element's type name.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_set_element_type (ESoapMessage *msg, const gchar *xsi_type)
@@ -631,7 +631,7 @@ e_soap_message_set_element_type (ESoapMessage *msg, const gchar *xsi_type)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	xmlNewNsProp (priv->last_node, priv->xsi_ns, (const xmlChar *)"type", (const xmlChar *)xsi_type);
 }
@@ -642,7 +642,7 @@ e_soap_message_set_element_type (ESoapMessage *msg, const gchar *xsi_type)
  *
  * Sets the current element's XML Schema xsi:null attribute.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_set_null (ESoapMessage *msg)
@@ -650,7 +650,7 @@ e_soap_message_set_null (ESoapMessage *msg)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	xmlNewNsProp (priv->last_node, priv->xsi_ns, (const xmlChar *)"null", (const xmlChar *)"1");
 }
@@ -665,7 +665,7 @@ e_soap_message_set_null (ESoapMessage *msg)
  *
  * Adds an XML attribute to the current element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_add_attribute (ESoapMessage *msg,
@@ -677,7 +677,7 @@ e_soap_message_add_attribute (ESoapMessage *msg,
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	xmlNewNsProp (priv->last_node,
 		      fetch_ns (msg, prefix, ns_uri),
@@ -692,7 +692,7 @@ e_soap_message_add_attribute (ESoapMessage *msg,
  *
  * Adds a new XML namespace to the current element.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_add_namespace (ESoapMessage *msg, const gchar *prefix, const gchar *ns_uri)
@@ -700,7 +700,7 @@ e_soap_message_add_namespace (ESoapMessage *msg, const gchar *prefix, const gcha
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	xmlNewNs (priv->last_node, (const xmlChar *)(ns_uri ? ns_uri : ""), (const xmlChar *)prefix);
 }
@@ -714,7 +714,7 @@ e_soap_message_add_namespace (ESoapMessage *msg, const gchar *prefix, const gcha
  * default namespace becomes the namespace all non-explicitly
  * namespaced child elements fall into.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_set_default_namespace (ESoapMessage *msg, const gchar *ns_uri)
@@ -732,7 +732,7 @@ e_soap_message_set_default_namespace (ESoapMessage *msg, const gchar *ns_uri)
  * Sets the encodingStyle attribute on the current element to the
  * value of @enc_style.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_set_encoding_style (ESoapMessage *msg, const gchar *enc_style)
@@ -740,7 +740,7 @@ e_soap_message_set_encoding_style (ESoapMessage *msg, const gchar *enc_style)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	xmlNewNsProp (priv->last_node, priv->soap_ns, (const xmlChar *)"encodingStyle", (const xmlChar *)enc_style);
 }
@@ -751,7 +751,7 @@ e_soap_message_set_encoding_style (ESoapMessage *msg, const gchar *enc_style)
  *
  * Resets the internal XML representation of the SOAP message.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_reset (ESoapMessage *msg)
@@ -759,7 +759,7 @@ e_soap_message_reset (ESoapMessage *msg)
 	ESoapMessagePrivate *priv;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	xmlFreeDoc (priv->doc);
 	priv->doc = xmlNewDoc ((const xmlChar *)"1.0");
@@ -784,7 +784,7 @@ e_soap_message_reset (ESoapMessage *msg)
  *
  * Writes the serialized XML tree to the #SoupMessage's buffer.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 void
 e_soap_message_persist (ESoapMessage *msg)
@@ -794,7 +794,7 @@ e_soap_message_persist (ESoapMessage *msg)
 	gint len;
 
 	g_return_if_fail (E_IS_SOAP_MESSAGE (msg));
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	xmlDocDumpMemory (priv->doc, &body, &len);
 
@@ -814,7 +814,7 @@ e_soap_message_persist (ESoapMessage *msg)
  * Returns: The namespace prefix, or %NULL if no namespace exists
  * for the URI given.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 const gchar *
 e_soap_message_get_namespace_prefix (ESoapMessage *msg, const gchar *ns_uri)
@@ -823,7 +823,7 @@ e_soap_message_get_namespace_prefix (ESoapMessage *msg, const gchar *ns_uri)
 	xmlNsPtr ns = NULL;
 
 	g_return_val_if_fail (E_IS_SOAP_MESSAGE (msg), NULL);
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 	g_return_val_if_fail (ns_uri != NULL, NULL);
 
 	ns = xmlSearchNsByHref (priv->doc, priv->last_node, (const xmlChar *)ns_uri);
@@ -846,7 +846,7 @@ e_soap_message_get_namespace_prefix (ESoapMessage *msg, const gchar *ns_uri)
  *
  * Returns: the #xmlDocPtr representing the SOAP message.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 xmlDocPtr
 e_soap_message_get_xml_doc (ESoapMessage *msg)
@@ -854,7 +854,7 @@ e_soap_message_get_xml_doc (ESoapMessage *msg)
 	ESoapMessagePrivate *priv;
 
 	g_return_val_if_fail (E_IS_SOAP_MESSAGE (msg), NULL);
-	priv = E_SOAP_MESSAGE_GET_PRIVATE (msg);
+	priv = msg->priv;
 
 	return priv->doc;
 }
@@ -868,7 +868,7 @@ e_soap_message_get_xml_doc (ESoapMessage *msg)
  * Returns: a #ESoapResponse representing the response from
  * the server, or %NULL if there was an error.
  *
- * Since: 2.92
+ * Since: 3.0
  */
 ESoapResponse *
 e_soap_message_parse_response (ESoapMessage *msg)
