@@ -35,10 +35,6 @@
 #include "e-name-selector-dialog.h"
 #include "e-name-selector-entry.h"
 
-#define E_NAME_SELECTOR_DIALOG_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_NAME_SELECTOR_DIALOG, ENameSelectorDialogPrivate))
-
 typedef struct {
 	gchar        *name;
 
@@ -165,8 +161,9 @@ e_name_selector_dialog_init (ENameSelectorDialog *name_selector_dialog)
 	GtkWidget *status_message;
 	GtkWidget *source_combo;
 
-	name_selector_dialog->priv =
-		E_NAME_SELECTOR_DIALOG_GET_PRIVATE (name_selector_dialog);
+	name_selector_dialog->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		name_selector_dialog, E_TYPE_NAME_SELECTOR_DIALOG,
+		ENameSelectorDialogPrivate);
 
 	name_selector_box = gtk_vbox_new (FALSE, 6);
 	gtk_widget_show (name_selector_box);
@@ -427,7 +424,7 @@ e_name_selector_dialog_finalize (GObject *object)
 {
 	ENameSelectorDialogPrivate *priv;
 
-	priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (object);
+	priv = E_NAME_SELECTOR_DIALOG (object)->priv;
 
 	g_slist_foreach (priv->user_query_fields, (GFunc)g_free, NULL);
 	g_slist_free (priv->user_query_fields);
@@ -698,7 +695,7 @@ add_section (ENameSelectorDialog *name_selector_dialog,
 	g_assert (pretty_name != NULL);
 	g_assert (E_IS_DESTINATION_STORE (destination_store));
 
-	priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (name_selector_dialog);
+	priv = name_selector_dialog->priv;
 
 	memset (&section, 0, sizeof (Section));
 
@@ -950,7 +947,7 @@ source_changed (ENameSelectorDialog *name_selector_dialog,
 static void
 search_changed (ENameSelectorDialog *name_selector_dialog)
 {
-	ENameSelectorDialogPrivate *priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (name_selector_dialog);
+	ENameSelectorDialogPrivate *priv = name_selector_dialog->priv;
 	EContactStore *contact_store;
 	EBookQuery    *book_query;
 	GtkWidget     *combo_box;
